@@ -1,6 +1,7 @@
 import abc
 import datetime
 import logging
+import warnings
 from contextlib import suppress
 from decimal import Decimal, InvalidOperation
 from importlib import import_module
@@ -292,7 +293,6 @@ class Field(SupportedVersionInstanceMixIn, metaclass=abc.ABCMeta):
         is_searchable=True,
         is_attribute=False,
         default=None,
-        *args,
         **kwargs,
     ):
         self.name = name  # Usually set by the EWSMeta metaclass
@@ -309,7 +309,7 @@ class Field(SupportedVersionInstanceMixIn, metaclass=abc.ABCMeta):
         self.is_searchable = is_searchable
         # When true, this field is treated as an XML attribute instead of an element
         self.is_attribute = is_attribute
-        super().__init__(*args, **kwargs)
+        super().__init__(**kwargs)
 
     def clean(self, value, version=None):
         if version and not self.supports_version(version):
@@ -598,9 +598,10 @@ class DateTimeBackedDateField(DateField):
     def __init__(self, *args, **kwargs):
         # Not all fields assume a default time of 00:00, so make this configurable
         self._default_time = kwargs.pop("default_time", datetime.time(0, 0))
-        super().__init__(*args, **kwargs)
         # Create internal field to handle datetime-only logic
         self._datetime_field = DateTimeField(*args, **kwargs)
+        kwargs.pop("allow_naive", None)
+        super().__init__(*args, **kwargs)
 
     def date_to_datetime(self, value):
         return self._datetime_field.value_cls.combine(value, self._default_time).replace(tzinfo=UTC)
@@ -665,6 +666,10 @@ class DateTimeField(FieldURIField):
 
     value_cls = EWSDateTime
 
+    def __init__(self, *args, **kwargs):
+        self.allow_naive = kwargs.pop("allow_naive", False)
+        super().__init__(*args, **kwargs)
+
     def clean(self, value, version=None):
         if isinstance(value, datetime.datetime):
             if not value.tzinfo:
@@ -686,8 +691,10 @@ class DateTimeField(FieldURIField):
                         tz = account.default_timezone
                         log.info("Found naive datetime %s on field %s. Assuming timezone %s", e.local_dt, self.name, tz)
                         return e.local_dt.replace(tzinfo=tz)
-                    # There's nothing we can do but return the naive date. It's better than assuming e.g. UTC.
-                    log.warning("Returning naive datetime %s on field %s", e.local_dt, self.name)
+                    if not self.allow_naive:
+                        # There's nothing we can do but return the naive date. It's better than assuming e.g. UTC.
+                        # Making this a hard error is probably too risky. Warn instead.
+                        log.warning("Returning naive datetime %s on field %s", e.local_dt, self.name)
                     return e.local_dt
                 log.info("Cannot convert value '%s' on field '%s' to type %s", val, self.name, self.value_cls)
                 return None
@@ -739,16 +746,21 @@ class TimeZoneField(FieldURIField):
     def from_xml(self, elem, account):
         field_elem = elem.find(self.response_tag())
         if field_elem is not None:
-            ms_id = field_elem.get("Id")
-            ms_name = field_elem.get("Name")
+            tz_id = field_elem.get("Id") or field_elem.get("Name")
             try:
-                return self.value_cls.from_ms_id(ms_id or ms_name)
+                return self.value_cls.from_ms_id(tz_id)
             except UnknownTimeZone:
-                log.warning(
-                    "Cannot convert value '%s' on field '%s' to type %s (unknown timezone ID)",
-                    (ms_id or ms_name),
-                    self.name,
-                    self.value_cls,
+                warnings.warn(
+                    f"""\
+Cannot convert value {tz_id!r} on field {self.name!r} to type {self.value_cls.__name__!r} (unknown timezone ID).
+You can fix this by adding a custom entry into the timezone translation map:
+
+from exchangelib.winzone import MS_TIMEZONE_TO_IANA_MAP, CLDR_TO_MS_TIMEZONE_MAP
+
+# Replace "Some_Region/Some_Location" with a reasonable value from CLDR_TO_MS_TIMEZONE_MAP.keys()
+MS_TIMEZONE_TO_IANA_MAP[{tz_id!r}] = "Some_Region/Some_Location"
+
+# Your code here"""
                 )
                 return None
         return self.default
@@ -1169,6 +1181,19 @@ class MailboxListField(EWSElementListField):
         return super().clean(value, version=version)
 
 
+class AddressListField(EWSElementListField):
+    def __init__(self, *args, **kwargs):
+        from .properties import Address
+
+        kwargs["value_cls"] = Address
+        super().__init__(*args, **kwargs)
+
+    def clean(self, value, version=None):
+        if value is not None:
+            value = [self.value_cls(email_address=s) if isinstance(s, str) else s for s in value]
+        return super().clean(value, version=version)
+
+
 class MemberListField(EWSElementListField):
     def __init__(self, *args, **kwargs):
         from .properties import Member
@@ -1311,6 +1336,9 @@ class NamedSubField(SubField):
 class IndexedField(EWSElementField, metaclass=abc.ABCMeta):
     """A base class for all indexed fields."""
 
+    is_list = True
+    is_complex = True
+
     PARENT_ELEMENT_NAME = None
 
     def __init__(self, *args, **kwargs):
@@ -1331,16 +1359,15 @@ class IndexedField(EWSElementField, metaclass=abc.ABCMeta):
         return hash(self.field_uri)
 
 
-class EmailAddressesField(IndexedField):
-    is_list = True
-    is_complex = True
-
-    PARENT_ELEMENT_NAME = "EmailAddresses"
+class SingleFieldIndexedField(IndexedField):
+    """A base class for all single-field indexed fields."""
 
     def __init__(self, *args, **kwargs):
-        from .indexed_properties import EmailAddress
+        from .indexed_properties import SingleFieldIndexedElement
 
-        kwargs["value_cls"] = EmailAddress
+        value_cls = kwargs["value_cls"]
+        if not issubclass(value_cls, SingleFieldIndexedElement):
+            raise TypeError(f"'value_cls' {value_cls!r} must be a subclass of type {SingleFieldIndexedElement}")
         super().__init__(*args, **kwargs)
 
     def clean(self, value, version=None):
@@ -1349,19 +1376,37 @@ class EmailAddressesField(IndexedField):
             if len(value) > len(default_labels):
                 raise ValueError(f"This field can handle at most {len(default_labels)} values (value: {value})")
             tmp = []
+            value_field_name = self.value_cls.value_field(version=version).name
             for s, default_label in zip(value, default_labels):
                 if not isinstance(s, str):
                     tmp.append(s)
                     continue
-                tmp.append(self.value_cls(email=s, label=default_label))
+                tmp.append(self.value_cls(**{"label": default_label, value_field_name: s}))
             value = tmp
         return super().clean(value, version=version)
 
 
-class PhoneNumberField(IndexedField):
-    is_list = True
-    is_complex = True
+class EmailAddressesField(SingleFieldIndexedField):
+    PARENT_ELEMENT_NAME = "EmailAddresses"
 
+    def __init__(self, *args, **kwargs):
+        from .indexed_properties import EmailAddress
+
+        kwargs["value_cls"] = EmailAddress
+        super().__init__(*args, **kwargs)
+
+
+class ImAddressField(SingleFieldIndexedField):
+    PARENT_ELEMENT_NAME = "ImAddresses"
+
+    def __init__(self, *args, **kwargs):
+        from .indexed_properties import ImAddress
+
+        kwargs["value_cls"] = ImAddress
+        super().__init__(*args, **kwargs)
+
+
+class PhoneNumberField(SingleFieldIndexedField):
     PARENT_ELEMENT_NAME = "PhoneNumbers"
 
     def __init__(self, *args, **kwargs):
@@ -1717,3 +1762,81 @@ class GenericEventListField(EWSElementField):
                 continue
             events.append(value_cls.from_xml(elem=event, account=account))
         return events or self.default
+
+
+FLAG_ACTION_CHOICES = [
+    Choice("Any"),
+    Choice("Call"),
+    Choice("DoNotForward"),
+    Choice("FollowUp"),
+    Choice("FYI"),
+    Choice("Forward"),
+    Choice("NoResponseNecessary"),
+    Choice("Read"),
+    Choice("Reply"),
+    Choice("ReplyToAll"),
+    Choice("Review"),
+]
+
+
+class FlaggedForActionField(ChoiceField):
+    """
+    A field specifies the flag for action value that
+    must appear on incoming messages in order for the condition
+    or exception to apply.
+    """
+
+    def __init__(self, *args, **kwargs):
+        kwargs["choices"] = FLAG_ACTION_CHOICES
+        super().__init__(*args, **kwargs)
+
+
+IMPORTANCE_CHOICES = [
+    Choice("Low"),
+    Choice("Normal"),
+    Choice("High"),
+]
+
+
+class ImportanceField(ChoiceField):
+    """
+    A field that describes the importance of an item or
+    the aggregated importance of all items in a conversation
+    in the current folder.
+    """
+
+    def __init__(self, *args, **kwargs):
+        kwargs["choices"] = IMPORTANCE_CHOICES
+        super().__init__(*args, **kwargs)
+
+
+SENSITIVITY_CHOICES = [
+    Choice("Normal"),
+    Choice("Personal"),
+    Choice("Private"),
+    Choice("Confidential"),
+]
+
+
+class SensitivityField(ChoiceField):
+    """A field that indicates the sensitivity level of an item."""
+
+    def __init__(self, *args, **kwargs):
+        kwargs["choices"] = SENSITIVITY_CHOICES
+        super().__init__(*args, **kwargs)
+
+
+class FolderActionField(EWSElementField):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+    def clean(self, value, version=None):
+        from .folders import DistinguishedFolderId, Folder
+
+        if isinstance(value, Folder):
+            folder_id = value.to_id()
+            if isinstance(folder_id, DistinguishedFolderId):
+                value = self.value_cls(distinguished_folder_id=folder_id)
+            else:
+                value = self.value_cls(folder_id=folder_id)
+        return super().clean(value, version=version)
